CREATE DATABASE `mm` /*!40100 DEFAULT CHARACTER SET utf8 COLLATE utf8_czech_ci */;
USE `mm`;
SET CHARACTER SET utf8;

CREATE TABLE `map` (
  `id_play` int(11) NOT NULL,
  `x` int(11) NOT NULL,
  `y` int(11) NOT NULL,
  `id_tile` int(11) NOT NULL,
  KEY `id_play` (`id_play`),
  KEY `id_tile` (`id_tile`),
  CONSTRAINT `map_ibfk_1` FOREIGN KEY (`id_play`) REFERENCES `play` (`id_play`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `map_ibfk_2` FOREIGN KEY (`id_tile`) REFERENCES `tile` (`id_tile`) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `map` VALUES ('1', '0', '0', '1');
INSERT INTO `map` VALUES ('1', '1', '0', '1');
INSERT INTO `map` VALUES ('1', '0', '1', '1');
INSERT INTO `map` VALUES ('1', '1', '1', '1');

CREATE TABLE `play` (
  `id_play` int(11) NOT NULL auto_increment,
  `id_user` int(11) NOT NULL COMMENT 'spravce hry',
  `date_start` datetime NOT NULL,
  `id_turn_time` int(11) NOT NULL,
  `turn` int(11) NOT NULL COMMENT 'kolikate kolo se hraje',
  `state` enum('create','sign','play','finish') collate utf8_czech_ci NOT NULL,
  `x` int(11) NOT NULL,
  `y` int(11) NOT NULL,
  `title` char(100) collate utf8_czech_ci NOT NULL,
  `text` text collate utf8_czech_ci NOT NULL,
  PRIMARY KEY  (`id_play`),
  KEY `id_user` (`id_user`),
  KEY `date_start` (`date_start`),
  KEY `state` (`state`),
  KEY `id_turn_time` (`id_turn_time`),
  CONSTRAINT `play_ibfk_1` FOREIGN KEY (`id_user`) REFERENCES `user` (`id_user`) ON UPDATE CASCADE,
  CONSTRAINT `play_ibfk_2` FOREIGN KEY (`id_turn_time`) REFERENCES `turn_time` (`id_turn_time`) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `play` VALUES ('1', '1', '2007-08-01 10:00:00', '1', '0', 'sign', '2', '2', 'Borin Nightmare', 'Popis tohoto skvělého scénáře, jehož sláva hvězd se dotýká.');

CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `play_list` AS select `play`.`id_play` AS `id_play`,`play`.`id_user` AS `id_user`,`play`.`date_start` AS `date_start`,`play`.`id_turn_time` AS `id_turn_time`,`play`.`turn` AS `turn`,`play`.`state` AS `state`,`play`.`x` AS `x`,`play`.`y` AS `y`,`play`.`title` AS `title`,`play`.`text` AS `text`,`turn_time`.`time_title` AS `time_title`,`turn_time`.`turn_time` AS `turn_time`,`user`.`nick` AS `nick` from ((`play` join `turn_time` on((`play`.`id_turn_time` = `turn_time`.`id_turn_time`))) join `user` on((`play`.`id_user` = `user`.`id_user`)));

CREATE TABLE `play_side` (
  `id_play` int(11) NOT NULL,
  `id_side` int(11) NOT NULL,
  `min` int(11) NOT NULL,
  `max` int(11) NOT NULL,
  `current` int(11) NOT NULL,
  `missing` int(11) NOT NULL,
  `free` int(11) NOT NULL,
  UNIQUE KEY `id_play` (`id_play`,`id_side`),
  KEY `id_side` (`id_side`),
  CONSTRAINT `play_side_ibfk_3` FOREIGN KEY (`id_play`) REFERENCES `play` (`id_play`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `play_side_ibfk_4` FOREIGN KEY (`id_side`) REFERENCES `side` (`id_side`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `play_side` VALUES ('1', '1', '0', '3', '0', '0', '3');
INSERT INTO `play_side` VALUES ('1', '2', '1', '3', '1', '0', '2');
INSERT INTO `play_side` VALUES ('1', '3', '1', '3', '0', '1', '3');

CREATE TABLE `play_user` (
  `id_play` int(11) NOT NULL,
  `id_user` int(11) NOT NULL,
  `id_side` int(11) NOT NULL,
  UNIQUE KEY `id_play` (`id_play`,`id_user`),
  KEY `id_user` (`id_user`),
  KEY `id_side` (`id_side`),
  CONSTRAINT `play_user_ibfk_1` FOREIGN KEY (`id_play`) REFERENCES `play` (`id_play`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `play_user_ibfk_2` FOREIGN KEY (`id_user`) REFERENCES `user` (`id_user`) ON DELETE CASCADE ON UPDATE CASCADE,
  CONSTRAINT `play_user_ibfk_3` FOREIGN KEY (`id_side`) REFERENCES `side` (`id_side`) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `play_user` VALUES ('1', '1', '2');

CREATE TABLE `right` (
  `id_right` int(11) NOT NULL auto_increment,
  `code` char(100) collate utf8_czech_ci NOT NULL,
  PRIMARY KEY  (`id_right`),
  UNIQUE KEY `code` (`code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `right` VALUES ('1', 'login');

CREATE TABLE `role` (
  `id_role` int(11) NOT NULL auto_increment,
  `title` char(100) collate utf8_czech_ci NOT NULL,
  `default` tinyint(4) NOT NULL,
  PRIMARY KEY  (`id_role`),
  KEY `title` (`title`),
  KEY `default` (`default`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `role` VALUES ('1', 'common', '1');

CREATE TABLE `role_right` (
  `id_role` int(11) NOT NULL,
  `id_right` int(11) NOT NULL,
  UNIQUE KEY `id_role` (`id_role`,`id_right`),
  KEY `id_right` (`id_right`),
  CONSTRAINT `role_right_ibfk_1` FOREIGN KEY (`id_role`) REFERENCES `role` (`id_role`) ON UPDATE CASCADE,
  CONSTRAINT `role_right_ibfk_2` FOREIGN KEY (`id_right`) REFERENCES `right` (`id_right`) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `role_right` VALUES ('1', '1');

CREATE TABLE `side` (
  `id_side` int(11) NOT NULL auto_increment,
  `title` char(100) collate utf8_czech_ci NOT NULL,
  PRIMARY KEY  (`id_side`),
  KEY `title` (`title`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `side` VALUES ('2', 'křováci');
INSERT INTO `side` VALUES ('1', 'piráti');
INSERT INTO `side` VALUES ('3', 'vojáci');

CREATE TABLE `tile` (
  `id_tile` int(11) NOT NULL auto_increment,
  `type` enum('ground','shallow','deep') collate utf8_czech_ci NOT NULL,
  `default` tinyint(4) NOT NULL,
  PRIMARY KEY  (`id_tile`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `tile` VALUES ('1', 'deep', '1');
INSERT INTO `tile` VALUES ('2', 'shallow', '0');
INSERT INTO `tile` VALUES ('3', 'ground', '0');

CREATE TABLE `turn_time` (
  `id_turn_time` int(11) NOT NULL auto_increment,
  `turn_time` time NOT NULL,
  `time_title` char(100) collate utf8_czech_ci NOT NULL,
  PRIMARY KEY  (`id_turn_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `turn_time` VALUES ('1', '01:00:00', '1 hodina');

CREATE TABLE `user` (
  `id_user` int(11) NOT NULL auto_increment,
  `id_role` int(11) NOT NULL,
  `login` char(100) collate utf8_czech_ci NOT NULL,
  `password_md5` char(64) collate utf8_czech_ci NOT NULL,
  `nick` char(100) collate utf8_czech_ci NOT NULL,
  `date_register` datetime NOT NULL,
  `date_hit` datetime NOT NULL,
  `date_login` datetime NOT NULL,
  `date_logout` datetime NOT NULL,
  PRIMARY KEY  (`id_user`),
  KEY `id_role` (`id_role`),
  CONSTRAINT `user_ibfk_1` FOREIGN KEY (`id_role`) REFERENCES `role` (`id_role`) ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_czech_ci;
INSERT INTO `user` VALUES ('1', '1', 'borin', 'bbd89fe88742266deab019c74d3de359', 'Borin', '2007-07-26 18:25:58', '2007-07-30 17:03:16', '2007-07-30 17:02:46', '2007-07-30 17:03:16');

CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`localhost` SQL SECURITY DEFINER VIEW `user_rights` AS select `user`.`id_user` AS `id_user`,`right`.`id_right` AS `id_right`,`right`.`code` AS `code` from (((`right` join `role_right` on((`right`.`id_right` = `role_right`.`id_right`))) join `role` on((`role_right`.`id_role` = `role`.`id_role`))) join `user` on((`role_right`.`id_role` = `user`.`id_role`)));

DELIMITER ;;

CREATE TRIGGER `play_insert` AFTER INSERT ON `play` FOR EACH ROW BEGIN

DECLARE tile INT(11);
DECLARE x INT(11);
DECLARE y INT(11);

SELECT id_tile INTO tile FROM tile WHERE `default` = 1 LIMIT 1;

SET y = 0;
WHILE y < NEW.y DO
  SET x = 0;
  WHILE x < NEW.x DO
    INSERT INTO map(id_play, x, y, id_tile) VALUES(NEW.id_play, x, y, tile);
    SET x = x + 1;
  END WHILE;
  SET y = y + 1;
END WHILE;

INSERT INTO play_side(id_play, id_side, min, max, current) SELECT NEW.id_play, id_side, 0, 0, 0 FROM side;

END;;

CREATE TRIGGER `play_side_insert` BEFORE INSERT ON `play_side` FOR EACH ROW BEGIN
  IF NEW.current < NEW.min THEN
    SET NEW.missing = NEW.min - NEW.current;
  ELSE
    SET NEW.missing = 0;
  END IF;
  SET NEW.free = NEW.max - NEW.current;
END;;

CREATE TRIGGER `play_side_update` BEFORE UPDATE ON `play_side` FOR EACH ROW BEGIN
  IF NEW.current < NEW.min THEN
    SET NEW.missing = NEW.min - NEW.current;
  ELSE
    SET NEW.missing = 0;
  END IF;
  SET NEW.free = NEW.max - NEW.current;
END;;

CREATE TRIGGER `play_user_insert` AFTER INSERT ON `play_user` FOR EACH ROW UPDATE play_side SET current = current + 1 WHERE id_play = NEW.id_play AND id_side = NEW.id_side;;

CREATE TRIGGER `play_user_update` AFTER UPDATE ON `play_user` FOR EACH ROW BEGIN
UPDATE play_side SET current = current + 1 WHERE id_play = NEW.id_play AND id_side = NEW.id_side;
UPDATE play_side SET current = current - 1 WHERE id_play = OLD.id_play AND id_side = OLD.id_side;
END;;

CREATE TRIGGER `play_user_delete` AFTER DELETE ON `play_user` FOR EACH ROW UPDATE play_side SET current = current - 1 WHERE id_play = OLD.id_play AND id_side = OLD.id_side;;

CREATE TRIGGER `right_delete` BEFORE DELETE ON `right` FOR EACH ROW DELETE FROM role_right WHERE id_right = OLD.id_right;;

CREATE TRIGGER `role_delete` BEFORE DELETE ON `role` FOR EACH ROW DELETE FROM role_right WHERE id_role = OLD.id_role;;

CREATE TRIGGER `user_insert` BEFORE INSERT ON `user` FOR EACH ROW BEGIN
  DECLARE count INT(11);
  DECLARE role INT(11);
  SELECT COUNT(*) INTO count FROM role WHERE id_role = NEW.id_role LIMIT 1;
  IF count = 0 THEN
    SELECT id_role INTO role FROM role WHERE `default` = 1 LIMIT 1;
    SET NEW.id_role = role;
  END IF;
END;;

DELIMITER ;