<?php

/**
 *  Addslashes i na pole
 *  @param      mixed       $x      string nebo pole, ktere ma byt zaslashovano
 *  @return     mixed               zaslashovany vstup  
 */
function g_addslashes($x) {
    if (is_array($x)) {
        foreach ($x as $key => $value) {
            $x[$key] = g_addslashes($value);
        }
        return $x;
    } else {
        return addslashes($x);
    }
}

/**
 *  Vrat url skladajici se ze zadanych parametru.
 *  @param      ...         vsechny zadane argumenty se spoji do odkazu: /arg1/arg2...
 *                          s ohledem na URL_PREFIX a URL_SEPARATOR
 *  @return     string      vysledna URL
 */
function url() {
    $args = func_get_args();
    return empty($args) ? './' : URL_PREFIX.implode(URL_SEPARATOR, $args);
}

/**
 *  Presmeruj prohlizec na danou URL.
 *  @param      string      $url            na jakou adresu presmerovat
 *  @return     void
 */
function redirect($url) {
    header('Location: '.$url);
    exit();
}

/**
 *  Vrat i-ty parametr predany v URL (parametry v URL jsou oddeleny URL_SEPARATOR-em)
 *  nebo jiz pojmenovany parametr volani skriptu (k pojmenovani dojde v query_check_params()
 *  a nazvy se definuji v poli $_query_param v config.access.php).
 *  @param      mixed       $i          poradi parametru nebo nazev parametru
 *  @return     string                  hodnota parametru (neexistuje-li, vraci se prazdny string)
 */
function query($i) {
    if (is_int($i)) {
        global $_QUERY;
        return empty($_QUERY[$i]) ? '' : $_QUERY[$i];
    } else {
        global $_PARAM;
        return empty($_PARAM[$i]) ? '' : $_PARAM[$i];
    }
}

/**
 *  Existuje dana stranka v seznamu skriptu?
 *  @param      string      $query      nazev skriptu
 *  @return     bool                    true pokud existuje, jinak false
 */
function query_exists($query) {
    global $_query_param;
    return isset($_query_param[$query]);
}

/**
 *  Zkontroluj, zda je skript volan s platnymi parametry.
 *  @param      string      $query      nazev skriptu
 *  @return     bool                    true pokud jsou parametry platne, jinak false
 */
function query_check_params($query) {
    global $_query_param, $_PARAM;
    $i = 1;
    foreach ($_query_param[$query] as $param => $function) {
        if (!$function($_PARAM[$param] = query($i++))) {
            return false;
        }
    }
    return true;
}

/**
 *  Zkontroluj, zda jsou splnena vsechna potrebna prava pro volani skriptu.
 *  @param      string      $query      nazev skriptu
 *  @return     bool                    true pokud jsou prava splnena, jinak false
 */
function query_check_rights($query) {
    global $_query_right;
    eval($_query_right[$query]);
    return $ok === true;
}

/**
 *  Je zadany string integer hodnotou?
 *  @param      string      $string     testovany string
 *  @return     bool        true pokud string vyjadruje integer
 */
function isInt($string) {
    return preg_match('/^-?[0-9]+$/', $string);
}

/**
 *  Je zadany string jednoduchym identifikatorem?
 *  @param      string      $string     testovany string
 *  @return     bool        true pokud string vyjadruje jednoduchy identifikator
 */
function isIdent($string) {
    return preg_match('/^[a-z0-9]+(-[a-z0-9]+)*$/', $string);
}

/**
 *  Je zadany string platnym datumem ve formatu YYYY-MM-DD?
 *  @param      string      $string     testovany string
 *  @return     bool        true pokud se jedna o spravne zadany datum  
 */
function isDate($string) {
    $date = explode('-', $string);
    if (count($date) != 3) {
        return false;
    }
    list($year, $month, $day) = $date;
    if (strlen($year) != 4 || strspn($year, '0123456789') != 4 || strlen($month) != 2 || strspn($month, '0123456789') != 2 || strlen($day) != 2 || strspn($day, '0123456789') != 2) {
        return false;
    }
    return checkdate($month + 0, $day + 0, $year + 0);
}

/**
 *  Je zadany string jednoduchym identifikatorem nebo pripadne prazdny?
 *  @param      string      $string     testovany string
 *  @return     bool        true pokud string vyjadruje jednoduchy identifikator nebo je prazdny
 */
function mayIdent($string) {
    return empty($string) || preg_match('/^[a-z0-9]+(-[a-z0-9]+)*$/', $string);
}

/**
 *  Ziskej hodnotu session promenne predavane mezi strankami (napriklad pri
 *  filtrovani hodnot v nejake tabulce apod.)
 *  @param      string      $name       nazev session-promenne, v niz se predava urcita hodnota
 *  @param      string      $query      nazev query-promenne, jejiz hodnotou se da tato promenna zmenit
 *  @param      mixed       $default    vychozi hodnota promenne
 *  @return     mixed                   zjistena hodnota promenne
 */
function state_var($name, $query, $default = '') {
    if (query($query) != '') {
        $_SESSION[$name] = query($query);
    }
    if (empty($_SESSION[$name])) {
        $_SESSION[$name] = $default;
    }
    return $_SESSION[$name];
}

/**
 *  Zjisti hodnotu POST promenne, pokud zadnou hodnotu nema, vrat zadanou vychozi hodnotu.
 *  @param      string      $key        jmeno POST promenne
 *  @param      mixed       $default    vychozi hodnota vracena pri neexistenci dane POST promenne
 *  @return     mixed                   hodnota dane POST promenne nebo zadana vychozi hodnota
 */
function post($key, $default = NULL) {
    return isset($_POST[$key]) ? $_POST[$key] : $default;
}

?>
